api.sampledb.v1.submission package — Argus-Toolbelt 1.0 documentation

# api.sampledb.v1.submission package

## Submodules

## api.sampledb.v1.submission.submission_search module

Autogenerated API

`api.sampledb.v1.submission.submission_search.` `get_submission_by_id`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch submission info identified by id. (DEV)

  Return type: | `dict`
  Parameters: | id (int) – Submission ID
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 836, “limit”: 574, “responseCode”: 200, “count”: 329, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Nation want listen key.”, “messageTemplate”: “Road popular pattern way check under item.”, “field”: “Compare difference outside usually trip describe base civil.”, “parameter”: {}, “timestamp”: 854002430}], “currentPage”: 998, “size”: 386}

`api.sampledb.v1.submission.submission_search.` `search_meta_submissions`(customerID: list = None, tlp: list = None, keywords: list = None, startTimestamp: int = None, endTimestamp: int = None, includeAnonymousResults: bool = 'True', limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search for submissions matching given search criteria (DEV)

  Return type: | `dict`
  Parameters: | customerID (list) – Set of customer IDs containing submissions. If not specified, search will be performed against all accessible customers. tlp (list) – Set of TLPs to search for. If not specified, search will be performed against all TLPs (WHITE, GREEN, AMBER, RED). keywords (list) – A set of keywords matched against the metafields of the submission. startTimestamp (int) – Start of time search period for submission creation date. (default 7 days before timestamp of request.) endTimestamp (int) – End of time search period for submission creation date. (default Timestamp of request.) includeAnonymousResults (bool) – Whether include anonymous results (default true) limit (int) – Set this value to set max number of results. (default 25) offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. (default 0)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 241, “limit”: 478, “responseCode”: 200, “count”: 274, “data”: [{“id”: 86, “sha256”: “Ok TV catch pay world me way.”, “createdTimestamp”: 1223672081, “owner”: “Because door argue include size.”, “properties”: {“additionalProperties”: “Act bill section growth.”}, “tlp”: “WHITE”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Establish including before factor animal front serve.”, “messageTemplate”: “Eight another chair day population eat example.”, “field”: “By public political model both decision.”, “parameter”: {}, “timestamp”: 639679709}], “currentPage”: 516, “size”: 272}

## Module contents